from wagtail.test.utils import WagtailPageTests
from cjkcms.models import (
    CjkcmsArticlePage,
    CjkcmsArticleIndexPage,
)
from wagtail.test.utils.form_data import nested_form_data

from wagtail.models import Page
from cjkcms.models.cms_models import ArticlePage, ArticleIndexPage, WebPage


class ArticlePageTests(WagtailPageTests):
    """Tests CjkCms Article Pages"""

    def test_cannot_create_cjkcms_article_page(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        # Assert that a CjkcmsArticlePage can NOT be made here, it's abstract
        self.assertCanNotCreateAt(
            home_page, CjkcmsArticlePage, nested_form_data({"title": "Article"})
        )

    def test_cannot_create_cjkcms_article_index_page(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        # Assert that a CjkcmsArticleIndexPage can NOT be made here, it's abstract
        self.assertCanNotCreateAt(
            home_page, CjkcmsArticleIndexPage, nested_form_data({"title": "Article"})
        )

    def test_can_create_article_page(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        body = [
            {
                "type": "embed_video",
                "value": {
                    "url": "https://youtu.be/AxLgTxBLsgI",
                },
                "id": "6ffa1b27-d884-4a9b-ba35-66140ff8a0ee",
            }
        ]

        article_page = ArticlePage(title="Test Article", body=body)

        home_page.add_child(instance=article_page)
        article_page.save_revision().publish()

        ap = ArticlePage.objects.get(slug="test-article")
        self.assertEqual(ap.title, "Test Article")

    def test_can_create_article_index_page(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        # Assert that a ArticleIndexPage can be made here
        self.assertCanCreateAt(
            home_page, ArticleIndexPage, nested_form_data({"title": "Article Index"})
        )

    def test_create_index_with_articles(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        body = [
            {
                "type": "embed_video",
                "value": {
                    "url": "https://youtu.be/AxLgTxBLsgI",
                },
                "id": "6ffa1b27-d884-4a9b-ba35-66140ff8a0ee",
            }
        ]

        article_index_page = ArticleIndexPage(title="Index")
        home_page.add_child(instance=article_index_page)

        article_page = ArticlePage(title="Test Article 1", body=body)

        article_index_page.add_child(instance=article_page)
        article_page.save_revision().publish()

        article_page = ArticlePage(title="Test Article 2", body=body)

        article_index_page.add_child(instance=article_page)
        article_page.save_revision().publish()

        aps = ArticlePage.objects.filter(slug__startswith="test-article-")
        self.assertEqual(len(aps), 2)

    def test_create_index_with_articles_under_webpage(self):
        # Get the HomePage
        home_page = Page.objects.get(path="00010001")

        body = [
            {
                "type": "embed_video",
                "value": {
                    "url": "https://youtu.be/AxLgTxBLsgI",
                },
                "id": "6ffa1b27-d884-4a9b-ba35-66140ff8a0ee",
            }
        ]

        web_page = WebPage(title="Web Page")
        home_page.add_child(instance=web_page)
        web_page.save_revision().publish()

        article_index_page = ArticleIndexPage(title="Index")
        web_page.add_child(instance=article_index_page)
        article_index_page.save_revision().publish()

        article_page = ArticlePage(title="Test Article 1", body=body)

        article_index_page.add_child(instance=article_page)
        article_page.save_revision().publish()

        article_page = ArticlePage(title="Test Article 2", body=body)

        article_index_page.add_child(instance=article_page)
        article_page.save_revision().publish()

        aps = ArticlePage.objects.filter(slug__startswith="test-article-")
        self.assertEqual(len(aps), 2)



from .draftail_extensions import (
    register_inline_styling,
    register_block_feature,
    NewWindowExternalLinkHandler,
)
from .draftail_icons import DRAFTAIL_ICONS

__all__ = [
    "register_inline_styling",
    "register_block_feature",
    "NewWindowExternalLinkHandler",
    "DRAFTAIL_ICONS",
]



# Generated by Django 4.0.7 on 2022-08-13 15:17

import cjkcms.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cjkcms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='articleindexpage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
        migrations.AlterField(
            model_name='articlepage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
        migrations.AlterField(
            model_name='webpage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
    ]



# Generated by Django 4.1.3 on 2022-11-27 18:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cjkcms", "0003_alter_footer_content_alter_navbar_menu_items"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="articles_date_format",
            field=models.CharField(
                blank=True,
                default="Y-m-d",
                help_text="Format of the publication date in articles. Set blank to hide.",
                max_length=200,
                verbose_name="Date format in articles",
            ),
        ),
        migrations.AddField(
            model_name="layoutsettings",
            name="articles_show_author",
            field=models.BooleanField(
                default=True,
                help_text="If disabled, override by filling `display author as` in article",
                verbose_name="Show author in articles",
            ),
        ),
    ]



"""
Content blocks are for building complex, nested HTML structures that usually
contain sub-blocks, and may require javascript to function properly.
"""
from django.utils.translation import gettext_lazy as _
from wagtail import blocks
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail.images.blocks import ImageChooserBlock
from wagtail.snippets.blocks import SnippetChooserBlock

from .base_blocks import (
    BaseBlock,
    BaseLayoutBlock,
    ButtonMixin,
    CollectionChooserBlock,
    TagChooserBlock,
)
from .html_blocks import ButtonBlock
from cjkcms.settings import cms_settings


class AccordionBlock(BaseBlock):
    """
    Allows selecting an accordion snippet
    """

    accordion = SnippetChooserBlock("cjkcms.Accordion")

    class Meta:
        template = "cjkcms/blocks/accordion_block.html"
        icon = "bars"
        label = _("Accordion")
        label_format = _("Accordion")


class CardBlock(BaseBlock):
    """
    A component of information with image, text, and buttons.
    """

    image = ImageChooserBlock(
        required=False,
        max_length=255,
        label=_("Image"),
    )
    title = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Title"),
    )
    subtitle = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Subtitle"),
    )
    description = blocks.RichTextBlock(
        features=cms_settings.CJKCMS_RICHTEXT_FEATURES["default"],
        label=_("Body"),
    )
    links = blocks.StreamBlock(
        [("Links", ButtonBlock())],
        blank=True,
        required=False,
        label=_("Links"),
    )

    class Meta:
        template = "cjkcms/blocks/card_foot.html"
        icon = "list-alt"
        label = _("Card")
        label_format = _("{title} (Card)")

    def get_template(self, context=None):
        """Return the default_card_template declared in parent CardGrid,
        otherwise use the default template."""

        if (
            context
            and hasattr(context["self"], "__iter__")
            and "default_card_template" in context["self"]
            and context["self"]["default_card_template"]
        ):
            return context["self"]["default_card_template"]
        else:
            return super().get_template()


class CarouselBlock(BaseBlock):
    """
    Enables choosing a Carousel snippet.
    """

    carousel = SnippetChooserBlock("cjkcms.Carousel")

    class Meta:
        icon = "image"
        label = _("Carousel")
        label_format = _("Carousel")
        template = "cjkcms/blocks/carousel_block.html"


class ImageGalleryBlock(BaseBlock):
    """
    Show a collection of images with interactive previews that expand to
    full size images in a modal.
    """

    collection = CollectionChooserBlock(
        required=True,
        label=_("Image Collection"),
    )

    tag = TagChooserBlock(
        required=False,
        label=_("Limit to tag"),
    )

    class Meta:
        template = "cjkcms/blocks/image_gallery_block.html"
        icon = "image"
        label = _("Image Gallery")
        label_format = _("Image Gallery")


class ModalBlock(ButtonMixin, BaseLayoutBlock):
    """
    Renders a button that then opens a popup/modal with content.
    """

    header = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Modal heading"),
    )
    content = blocks.StreamBlock(
        [],
        label=_("Modal content"),
    )
    footer = blocks.StreamBlock(
        [
            (
                "text",
                blocks.CharBlock(
                    icon="file-text-o", max_length=255, label=_("Simple Text")
                ),
            ),  # noqa
            ("button", ButtonBlock()),
        ],
        required=False,
        label=_("Modal footer"),
    )

    class Meta:
        template = "cjkcms/blocks/modal_block.html"
        icon = "window-maximize"
        label = _("Modal")
        label_format = _("Modal")


class NavBaseLinkBlock(BaseBlock):
    display_text = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Display text"),
    )
    image = ImageChooserBlock(
        required=False,
        label=_("Image"),
    )
    visible_for = blocks.ChoiceBlock(
        choices=cms_settings.CJKCMS_AUTH_VISIBILITY_CHOICES,
        default=cms_settings.CJKCMS_AUTH_VISIBILITY_DEFAULT,
        required=False,
        label=_("Item visibility"),
    )


class NavExternalLinkBlock(NavBaseLinkBlock):
    """
    External link.
    """

    link = blocks.CharBlock(
        required=False,
        label=_("URL"),
    )

    class Meta:
        template = "cjkcms/blocks/external_link_block.html"
        label = _("External Link")
        label_format = "{display_text} (External Link)"


class NavPageLinkBlock(NavBaseLinkBlock):
    """
    Page link.
    """

    page = blocks.PageChooserBlock(
        label=_("Page"),
    )

    class Meta:
        template = "cjkcms/blocks/page_link_block.html"
        label = _("Page Link")
        label_format = "{display_text} (Page Link)"


class NavDocumentLinkBlock(NavBaseLinkBlock):
    """
    Document link.
    """

    document = DocumentChooserBlock(
        label=_("Document"),
    )

    class Meta:
        template = "cjkcms/blocks/document_link_block.html"
        label = _("Document Link")
        label_format = "{display_text} (Document Link)"


class NavSubLinkBlock(BaseBlock):
    """
    Streamblock for rendering nested sub-links.
    """

    sub_links = blocks.StreamBlock(
        [
            ("page_link", NavPageLinkBlock()),
            ("external_link", NavExternalLinkBlock()),
            ("document_link", NavDocumentLinkBlock()),
        ],
        required=False,
        label=_("Sub-links"),
    )


class NavExternalLinkWithSubLinkBlock(NavSubLinkBlock, NavExternalLinkBlock):
    """
    External link with option for sub-links.
    """

    class Meta:
        label = _("External link with sub-links")
        label_format = "{display_text} (External link with sub-links)"


class NavPageLinkWithSubLinkBlock(NavSubLinkBlock, NavPageLinkBlock):
    """
    Page link with option for sub-links or showing child pages.
    """

    show_child_links = blocks.BooleanBlock(
        required=False,
        default=False,
        label=_("Show child pages"),
        help_text=_(
            "Automatically show a link to the Page’s child pages as a dropdown menu."
        ),
    )

    class Meta:
        label = _("Page link with sub-links")
        label_format = "{display_text} (Page link with sub-links)"


class NavDocumentLinkWithSubLinkBlock(NavSubLinkBlock, NavDocumentLinkBlock):
    """
    Document link with option for sub-links.
    """

    class Meta:
        label = _("Document link with sub-links")
        label_format = "{display_text} (Document link with sub-links)"


class PriceListItemBlock(BaseBlock):
    """
    Represents one item in a PriceListBlock, such as an entree in a restaurant menu.
    """

    image = ImageChooserBlock(
        required=False,
        label=_("Image"),
    )
    name = blocks.CharBlock(
        required=True,
        max_length=255,
        label=_("Name"),
    )
    description = blocks.RichTextBlock(
        required=False,
        rows=4,
        label=_("Description"),
    )
    price = blocks.CharBlock(
        required=True,
        label=_("Price"),
        help_text=_("Any text here. Include currency sign if desired."),
    )

    class Meta:
        template = "cjkcms/blocks/pricelistitem_block.html"
        icon = "usd"
        label = _("Price List Item")
        label_format = _("Price List Item")


class PriceListBlock(BaseBlock):
    """
    A price list, such as a menu for a restaurant.
    """

    heading = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Heading"),
    )
    items = blocks.StreamBlock(
        [
            ("item", PriceListItemBlock()),
        ],
        label=_("Items"),
    )

    class Meta:
        template = "cjkcms/blocks/pricelist_block.html"
        icon = "usd"
        label = _("Price List")


class ReusableContentBlock(BaseBlock):
    """
    Enables choosing a ResusableContent snippet.
    """

    content = SnippetChooserBlock("cjkcms.ReusableContent")

    class Meta:
        icon = "recycle"
        label = _("Reusable Content")
        template = "cjkcms/blocks/reusable_content_block.html"



from django.utils.html import strip_tags
from django.utils.safestring import mark_safe


def get_richtext_preview(content, max_length=200):
    """Returns a shortened version of a richtext field's content,
    with HTML tags stripped, and trimmed to max_length.
    >>> get_richtext_preview('<h1><div>Hello </div>world</h1>')
    'Hello world'
    >>> get_richtext_preview('Hi worl\x64')
    'Hi world'"""
    # strip tags
    c = strip_tags(content)
    # truncate and add ellipses
    preview = f"{c[:max_length]}..." if len(c) > 200 else c
    return mark_safe(preview)



from django.urls import include, path
from wagtail.contrib.sitemaps.views import sitemap
from cjkcms import search_urls as cjkcms_search_urls

# from .settings import cms_settings
from cjkcms.views import (
    favicon,
    robots,
)

urlpatterns = [
    # CMS custom URLs
    path("favicon.ico", favicon, name="cjkcms_favicon"),
    path("robots.txt", robots, name="cjkcms_robots"),
    path("sitemap.xml", sitemap, name="cjkcms_sitemap"),
    # Search
    path("search/", include(cjkcms_search_urls)),
]



import contextlib
import string
import random

from bs4 import BeautifulSoup
from django import template
from django.conf import settings
from django.db.models.query import QuerySet

# from django.forms import ClearableFileInput
from django.utils.safestring import mark_safe
from wagtail.models import Collection
from wagtail.images.models import Image

from cjkcms import __version__

from cjkcms.blocks.base_blocks import CjkcmsAdvSettings
from cjkcms.forms import SearchForm
from cjkcms.models import Footer, Navbar
from cjkcms.settings import cms_settings
from datetime import datetime

from cjkcms.models.wagtailsettings_models import LayoutSettings

register = template.Library()


@register.filter
def is_advanced_setting(obj):
    return CjkcmsAdvSettings in (obj.__class__,) + obj.__class__.__bases__


@register.simple_tag
def cjkcms_version():
    return __version__


@register.simple_tag
def generate_random_id():
    value = "".join(
        random.choice(string.ascii_letters + string.digits) for _ in range(20)
    )
    return f"cms-{value}"


@register.simple_tag
def current_year():
    return datetime.now().year


@register.simple_tag
def brand_logo_long():
    return cms_settings.CJKCMS_BRAND_LOGO_LONG


@register.simple_tag
def brand_logo_square():
    return cms_settings.CJKCMS_BRAND_LOGO_SQUARE


# TODO: add a test
@register.simple_tag
def is_menu_item_dropdown(value):
    return len(value.get("sub_links", [])) > 0 or (
        value.get("show_child_links", False)
        and len(value.get("page", []).get_children().live()) > 0
    )


# TODO: add a test
@register.simple_tag(takes_context=True)
def is_active_page(context, curr_page, other_page):
    if hasattr(curr_page, "get_url") and hasattr(other_page, "get_url"):
        curr_url = curr_page.get_url(context["request"])
        other_url = other_page.get_url(context["request"])
        return curr_url == other_url
    return False


# TODO: add a test
@register.simple_tag
def get_pictures(collection_id, tag=None):
    collection = Collection.objects.get(id=collection_id)
    images = Image.objects.filter(collection=collection)
    if tag:
        images = images.filter(tags__name=tag)
    return images


@register.simple_tag(takes_context=True)
def get_navbar_css(context):
    layout = LayoutSettings.for_request(context["request"])
    fixed = "fixed-top" if layout.navbar_fixed else ""
    return " ".join(
        [
            fixed,
            layout.navbar_collapse_mode,
            layout.navbar_color_scheme,
            layout.navbar_format,
            layout.navbar_class,
        ]
    )


@register.simple_tag(takes_context=True)
def get_navbars(context) -> "QuerySet[Navbar]":
    layout = LayoutSettings.for_request(context["request"])
    navbarorderables = layout.site_navbar.all()
    return Navbar.objects.filter(navbarorderable__in=navbarorderables).order_by(
        "navbarorderable__sort_order"
    )


@register.simple_tag(takes_context=True)
def get_footers(context) -> "QuerySet[Footer]":
    layout = LayoutSettings.for_request(context["request"])
    footerorderables = layout.site_footer.all()
    return Footer.objects.filter(footerorderable__in=footerorderables).order_by(
        "footerorderable__sort_order"
    )


@register.simple_tag
def get_searchform(request=None):
    return SearchForm(request.GET) if request else SearchForm()


@register.filter
def cjkcms_settings(value):
    return getattr(cms_settings, value)


@register.filter
def django_settings(value):
    return getattr(settings, value)


@register.simple_tag
def query_update(querydict, key=None, value=None):
    """
    Alters querydict (request.GET) by updating/adding/removing key to value
    """
    get = querydict.copy()
    if key:
        if value:
            get[key] = value
        else:
            with contextlib.suppress(KeyError):
                del get[key]
    return get


@register.simple_tag
def render_iframe_from_embed(embed):
    soup = BeautifulSoup(embed.html, "html.parser")
    with contextlib.suppress(AttributeError, TypeError):
        iframe_tags = soup.find("iframe")
        iframe_tags["title"] = embed.title  # type: ignore
        return mark_safe(soup.prettify())
    return mark_safe(embed.html)


@register.filter
def map_to_bootstrap_alert(message_tag):
    """
    Converts a message level to a bootstrap 5 alert class
    """
    message_to_alert_dict = {
        "debug": "primary",
        "info": "info",
        "success": "success",
        "warning": "warning",
        "error": "danger",
    }

    try:
        return message_to_alert_dict[message_tag]
    except KeyError:
        return ""


@register.simple_tag(takes_context=True)
def can_show_item(context, item_visibility: str) -> bool:
    """
    Menu item visibility conditional on selection in cms_settings.AUTH_VISIBILITY_CHOICES
    """
    if item_visibility == "hidden":
        return False
    if item_visibility == "all":
        return True

    try:
        context["request"].user.is_authenticated
    except KeyError:
        return False
    is_auth = context["request"].user.is_authenticated
    return bool(
        is_auth
        and item_visibility == "auth-only"
        or not is_auth
        and item_visibility == "non-auth-only"
    )


@register.simple_tag(takes_context=True)
def link_display(context, text: str) -> str:
    """
    Check for double-curly braces + user.username/first_name/last_name/first_last_name.
    If found, display as requested from user record
    """
    if text not in {
        "{{ user.username }}",
        "{{ user.first_name }}",
        "{{ user.last_name }}",
        "{{ user.first_last_name }}",
    }:
        return text
    u = context["request"].user
    if text == "{{ user.username }}":
        return u.username
    if text == "{{ user.first_name }}":
        return u.first_name
    if text == "{{ user.last_name }}":
        return u.last_name
    return f"{u.first_name} {u.last_name}"


@register.filter
def get_name_of_class(class_type):
    if hasattr(class_type.__class__, "search_name"):
        return class_type.__class__.search_name
    elif hasattr(class_type.__class__, "_meta") and hasattr(
        class_type.__class__._meta, "verbose_name"
    ):
        return class_type.__class__._meta.verbose_name
    else:
        return class_type.__class__.__name__


@register.filter
def get_plural_name_of_class(class_type):
    if hasattr(class_type.__class__, "search_name_plural"):
        return class_type.__class__.search_name_plural
    elif hasattr(class_type.__class__, "_meta") and hasattr(
        class_type.__class__._meta, "verbose_name_plural"
    ):
        return class_type.__class__._meta.verbose_name_plural
    else:
        return f"{class_type.__class__.__name__}s"



from wagtail.embeds.models import Embed
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = "Removes all instances of the Embed model. "
    "Run this if protected vimeo embeds are failing."

    def handle(self, *args, **options):
        try:
            Embed.objects.all().delete()
            return "All Embed model instances were successfully deleted!"
        except Exception as e:
            return e



# Generated by Django 4.2.1 on 2023-06-04 21:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0008_alter_layoutsettings_navbar_langselector"),
    ]

    operations = [
        migrations.AddField(
            model_name="navbar",
            name="language",
            field=models.CharField(
                blank=True,
                choices=[("_all_", "All languages")],
                default="_all_",
                help_text="Select a language to limit display to specific locale.",
                max_length=10,
                verbose_name="Show in language",
            ),
        ),
    ]



# image_formats.py
from django.utils.html import format_html
from wagtail.images.formats import (
    Format,
    register_image_format,
    unregister_image_format,
)


class SurroundingDivImageFormat(Format):
    surrounding_classes = ""

    def __init__(self, name, label, classnames, filter_spec, surrounding_classes=""):
        self.surrounding_classes = surrounding_classes
        super().__init__(name, label, classnames, filter_spec)

    def image_to_html(self, image, alt_text, extra_attributes=None):

        default_html = super().image_to_html(image, alt_text, extra_attributes)

        return format_html(
            f'<div class="{self.surrounding_classes}">{default_html}</div>',
        )


# default left and right does not play well with bootstrap5
unregister_image_format("left")
unregister_image_format("right")

register_image_format(
    SurroundingDivImageFormat(
        "centered",
        "Centered",
        "bodytext-image",
        "width-640",
        surrounding_classes="d-flex justify-content-center",
    )
)

register_image_format(
    SurroundingDivImageFormat(
        "left",
        "Left-justified",
        "bodytext-image",
        "width-640",
        surrounding_classes="d-flex justify-content-start",
    )
)

register_image_format(
    SurroundingDivImageFormat(
        "right",
        "Right-justified",
        "bodytext-image",
        "width-640",
        surrounding_classes="d-flex justify-content-end",
    )
)

register_image_format(
    Format(
        "thumb-left",
        "Left-floating thumbnail",
        "bodytext-image float-start me-2",
        "width-200",
    )
)

register_image_format(
    Format(
        "thumb-right",
        "Right-floating thumbnail",
        "bodytext-image float-end ms-2",
        "width-200",
    )
)



import json

from datetime import timedelta
from urllib import request as urllib_request
from urllib.error import URLError
from urllib.parse import urlencode
from urllib.request import Request

from django.utils import timezone

from wagtail.embeds.exceptions import EmbedNotFoundException

from wagtail.embeds.finders.oembed import OEmbedFinder
from django.conf import settings


class OEmbedFinderWithReferer(OEmbedFinder):
    def find_embed(self, url, max_width=None, max_height=None):
        # Find provider
        endpoint = self._get_endpoint(url)
        if endpoint is None:
            raise EmbedNotFoundException

        # Work out params
        params = self.options.copy()
        params["url"] = url
        params["format"] = "json"
        params["referrerpolicy"] = "origin"
        if max_width:
            params["maxwidth"] = max_width
        if max_height:
            params["maxheight"] = max_height

        # Perform request
        request = Request(f"{endpoint}?{urlencode(params)}")
        request.add_header("User-agent", "Mozilla/5.0")
        # add referer to request header
        request.add_header("referer", settings.BASE_URL)
        try:
            r = urllib_request.urlopen(request)
            oembed = json.loads(r.read().decode("utf-8"))
        except (URLError, json.decoder.JSONDecodeError) as e:
            raise EmbedNotFoundException from e

        # Convert photos into HTML
        if oembed["type"] == "photo":
            html = '<img src="%s" alt="">' % (oembed["url"],)
        elif oembed["type"] == "video":
            html = oembed.get("html")
            # add referrerpolicty in front of iframe
            html = html[:7] + ' referrerpolicy="origin"' + html[7:]
        else:
            html = oembed.get("html")

        print(html)

        result = {
            "title": oembed.get("title", ""),
            "author_name": oembed.get("author_name", ""),
            "provider_name": oembed.get("provider_name", ""),
            "type": oembed["type"],
            "thumbnail_url": oembed.get("thumbnail_url"),
            "width": oembed.get("width"),
            "height": oembed.get("height"),
            "html": html,
        }

        try:
            cache_age = int(oembed["cache_age"])
        except (KeyError, TypeError, ValueError):
            pass
        else:
            result["cache_until"] = timezone.now() + timedelta(seconds=cache_age)

        return result



# Generated by Django 4.1.8 on 2023-04-16 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cjkcms", "0006_analyticssettings_consent_modal_layout_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="bootstrap_icons",
            field=models.BooleanField(
                default=False,
                help_text="Load bootstrap icons css from local/static folder",
                verbose_name="Bootstrap Icons CSS",
            ),
        ),
    ]
